@@ -1,5 +1,5 @@
 package Bio::Tools::Solubility::Wilkinson;
-our $VERSION = '0.093341';
+our $VERSION = '0.093360';
 
 
 
@@ -7,6 +7,8 @@ our $VERSION = '0.093341';
 
 use strict;
 use warnings;
+use Carp 'croak';
+
 use Sub::Exporter -setup => {
     exports => ['solubility'],
     groups  => { default => ['solubility'] },
@@ -23,7 +25,9 @@ use constant {
 
 
 sub solubility {
-    my $protein = shift or die "No protein argument";
+    my $protein = shift or croak "No protein argument";
+
+    $protein =~ s/\s+//g;
 
     my $CV      = _CV($protein);
     my $CV_norm = abs($CV - CVp);
@@ -68,28 +72,28 @@ Bio::Tools::Solubility::Wilkinson - Calculate the probability of a protein to be
 
 =head1 VERSION
 
-version 0.093341
+version 0.093360
 
 =head1 SYNOPSIS
 
     use Bio::Tools::Solubility::Wilkinson;
 
-    my $seq = 'MMAEELLVIKP...'
+    my $seq = 'MMAEELLVIKP...';
 
     my $s = solubility($seq);
 
 =head1 DESCRIPTION
 
 This module implements a simple method for the prediction of protein
-solubility, as described by Wilkinson, D.L. and Harrison [1]. It only
-takes the primary sequence of the protein as a parameter, and returns
-the calculated probability that the protein will be expressed in soluble
-form in E. Coli.
+solubility, as described by Wilkinson, D.L. and Harrison [1] and
+modified by Davis [2]. It only takes the primary sequence of the protein
+as a parameter, and returns the calculated probability that the protein
+will be expressed in soluble form in E. Coli.
 
 It uses aminoacid composition to compute the two main parameters found
 to have strong correlation with solubility: charge average and turn
 forming residue fraction. For a detailed description of the formula
-used, check the article by Harrison [2] in the L<References> section.
+used, check the article by Harrison [3] in the References section.
 
 =head1 METHODS
 
@@ -97,7 +101,8 @@ used, check the article by Harrison [2] in the L<References> section.
 
 Returns the probability of the sequence C<$seq> being soluble. C<$seq>
 should be a correct and validated protein sequence written in one-letter
-aminoacid code with no whitespace and no non-residue characters.
+aminoacid code. Any whitespace (spaces, newlines, tabs, etc) will be
+ignored.
 
     my $probability = solubility($seq);
 
@@ -123,11 +128,17 @@ is worth checking out.
 
 =over 4
 
-=item * [1] Wilkinson, D.L. and Harrison, R.G. (1991) BioTechnology 9, 443–448
-L<http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=1367308&dopt=Abstract>
+=item * [1] Wilkinson, D.L. and Harrison, R.G. (1991). I<Predicting the
+solubility of recombinant proteins in Escherichia coli> BioTechnology 9,
+443-448.
 
-=item * [2] R.G. Harrison. 2000. Expression of soluble heterologous proteins via
-fusion with NusA protein. inNovations. 11:4-7.
+=item * [2] Gregory D. Davis, Claude Elisee, Denton M. Newham, Roger G.
+Harrison (1999). I<New fusion protein systems designed to give soluble
+expression in Escherichia coli>. Biotechnology and Bioengineering Volume
+65 Issue 4, Pages 382 - 388
+
+=item * [3] R.G. Harrison. 2000. I<Expression of soluble heterologous
+proteins via fusion with NusA protein>. inNovations. 11:4-7.
 L<http://www.biotech.ou.edu/innovations.pdf>
 
 =back
@@ -151,4 +162,3 @@ __END__
 
 
 
-
